<?php
namespace PHPMaker2019\project_germanos;

// Session
if (session_status() !== PHP_SESSION_ACTIVE)
	session_start(); // Init session data

// Output buffering
ob_start(); 

// Autoload
include_once "autoload.php";
?>
<?php

// Write header
WriteHeader(FALSE);

// Create page object
$judgetype_edit = new judgetype_edit();

// Run the page
$judgetype_edit->run();

// Setup login status
SetupLoginStatus();
SetClientVar("login", LoginStatus());

// Global Page Rendering event (in userfn*.php)
Page_Rendering();

// Page Rendering event
$judgetype_edit->Page_Render();
?>
<?php include_once "header.php" ?>
<script>

// Form object
currentPageID = ew.PAGE_ID = "edit";
var fjudgetypeedit = currentForm = new ew.Form("fjudgetypeedit", "edit");

// Validate form
fjudgetypeedit.validate = function() {
	if (!this.validateRequired)
		return true; // Ignore validation
	var $ = jQuery, fobj = this.getForm(), $fobj = $(fobj);
	if ($fobj.find("#confirm").val() == "F")
		return true;
	var elm, felm, uelm, addcnt = 0;
	var $k = $fobj.find("#" + this.formKeyCountName); // Get key_count
	var rowcnt = ($k[0]) ? parseInt($k.val(), 10) : 1;
	var startcnt = (rowcnt == 0) ? 0 : 1; // Check rowcnt == 0 => Inline-Add
	var gridinsert = ["insert", "gridinsert"].includes($fobj.find("#action").val()) && $k[0];
	for (var i = startcnt; i <= rowcnt; i++) {
		var infix = ($k[0]) ? String(i) : "";
		$fobj.data("rowindex", infix);
		<?php if ($judgetype_edit->JudgeTypeID->Required) { ?>
			elm = this.getElements("x" + infix + "_JudgeTypeID");
			if (elm && !ew.isHidden(elm) && !ew.hasValue(elm))
				return this.onError(elm, "<?php echo JsEncode(str_replace("%s", $judgetype->JudgeTypeID->caption(), $judgetype->JudgeTypeID->RequiredErrorMessage)) ?>");
		<?php } ?>
		<?php if ($judgetype_edit->JudgeType->Required) { ?>
			elm = this.getElements("x" + infix + "_JudgeType");
			if (elm && !ew.isHidden(elm) && !ew.hasValue(elm))
				return this.onError(elm, "<?php echo JsEncode(str_replace("%s", $judgetype->JudgeType->caption(), $judgetype->JudgeType->RequiredErrorMessage)) ?>");
		<?php } ?>
		<?php if ($judgetype_edit->JudgeTypeEn->Required) { ?>
			elm = this.getElements("x" + infix + "_JudgeTypeEn");
			if (elm && !ew.isHidden(elm) && !ew.hasValue(elm))
				return this.onError(elm, "<?php echo JsEncode(str_replace("%s", $judgetype->JudgeTypeEn->caption(), $judgetype->JudgeTypeEn->RequiredErrorMessage)) ?>");
		<?php } ?>
		<?php if ($judgetype_edit->Notes->Required) { ?>
			elm = this.getElements("x" + infix + "_Notes");
			if (elm && !ew.isHidden(elm) && !ew.hasValue(elm))
				return this.onError(elm, "<?php echo JsEncode(str_replace("%s", $judgetype->Notes->caption(), $judgetype->Notes->RequiredErrorMessage)) ?>");
		<?php } ?>

			// Fire Form_CustomValidate event
			if (!this.Form_CustomValidate(fobj))
				return false;
	}

	// Process detail forms
	var dfs = $fobj.find("input[name='detailpage']").get();
	for (var i = 0; i < dfs.length; i++) {
		var df = dfs[i], val = df.value;
		if (val && ew.forms[val])
			if (!ew.forms[val].validate())
				return false;
	}
	return true;
}

// Form_CustomValidate event
fjudgetypeedit.Form_CustomValidate = function(fobj) { // DO NOT CHANGE THIS LINE!

	// Your custom validation code here, return false if invalid.
	return true;
}

// Use JavaScript validation or not
fjudgetypeedit.validateRequired = <?php echo json_encode(CLIENT_VALIDATE) ?>;

// Dynamic selection lists
// Form object for search

</script>
<script>

// Write your client script here, no need to add script tags.
</script>
<?php $judgetype_edit->showPageHeader(); ?>
<?php
$judgetype_edit->showMessage();
?>
<?php if (!$judgetype_edit->IsModal) { ?>
<form name="ew-pager-form" class="form-inline ew-form ew-pager-form" action="<?php echo CurrentPageName() ?>">
<?php if (!isset($judgetype_edit->Pager)) $judgetype_edit->Pager = new PrevNextPager($judgetype_edit->StartRec, $judgetype_edit->DisplayRecs, $judgetype_edit->TotalRecs, $judgetype_edit->AutoHidePager) ?>
<?php if ($judgetype_edit->Pager->RecordCount > 0 && $judgetype_edit->Pager->Visible) { ?>
<div class="ew-pager">
<span><?php echo $Language->Phrase("Page") ?>&nbsp;</span>
<div class="ew-prev-next"><div class="input-group input-group-sm">
<div class="input-group-prepend">
<!-- first page button -->
	<?php if ($judgetype_edit->Pager->FirstButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerFirst") ?>" href="<?php echo $judgetype_edit->pageUrl() ?>start=<?php echo $judgetype_edit->Pager->FirstButton->Start ?>"><i class="icon-first ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerFirst") ?>"><i class="icon-first ew-icon"></i></a>
	<?php } ?>
<!-- previous page button -->
	<?php if ($judgetype_edit->Pager->PrevButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerPrevious") ?>" href="<?php echo $judgetype_edit->pageUrl() ?>start=<?php echo $judgetype_edit->Pager->PrevButton->Start ?>"><i class="icon-prev ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerPrevious") ?>"><i class="icon-prev ew-icon"></i></a>
	<?php } ?>
</div>
<!-- current page number -->
	<input class="form-control" type="text" name="<?php echo TABLE_PAGE_NO ?>" value="<?php echo $judgetype_edit->Pager->CurrentPage ?>">
<div class="input-group-append">
<!-- next page button -->
	<?php if ($judgetype_edit->Pager->NextButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerNext") ?>" href="<?php echo $judgetype_edit->pageUrl() ?>start=<?php echo $judgetype_edit->Pager->NextButton->Start ?>"><i class="icon-next ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerNext") ?>"><i class="icon-next ew-icon"></i></a>
	<?php } ?>
<!-- last page button -->
	<?php if ($judgetype_edit->Pager->LastButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerLast") ?>" href="<?php echo $judgetype_edit->pageUrl() ?>start=<?php echo $judgetype_edit->Pager->LastButton->Start ?>"><i class="icon-last ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerLast") ?>"><i class="icon-last ew-icon"></i></a>
	<?php } ?>
</div>
</div>
</div>
<span>&nbsp;<?php echo $Language->Phrase("of") ?>&nbsp;<?php echo $judgetype_edit->Pager->PageCount ?></span>
<div class="clearfix"></div>
</div>
<?php } ?>
<div class="clearfix"></div>
</form>
<?php } ?>
<form name="fjudgetypeedit" id="fjudgetypeedit" class="<?php echo $judgetype_edit->FormClassName ?>" action="<?php echo CurrentPageName() ?>" method="post">
<?php if ($judgetype_edit->CheckToken) { ?>
<input type="hidden" name="<?php echo TOKEN_NAME ?>" value="<?php echo $judgetype_edit->Token ?>">
<?php } ?>
<input type="hidden" name="t" value="judgetype">
<input type="hidden" name="action" id="action" value="update">
<input type="hidden" name="modal" value="<?php echo (int)$judgetype_edit->IsModal ?>">
<?php if (!$judgetype_edit->IsMobileOrModal) { ?>
<div class="ew-desktop"><!-- desktop -->
<?php } ?>
<?php if ($judgetype_edit->IsMobileOrModal) { ?>
<div class="ew-edit-div"><!-- page* -->
<?php } else { ?>
<table id="tbl_judgetypeedit" class="table table-striped table-sm ew-desktop-table"><!-- table* -->
<?php } ?>
<?php if ($judgetype->JudgeType->Visible) { // JudgeType ?>
<?php if ($judgetype_edit->IsMobileOrModal) { ?>
	<div id="r_JudgeType" class="form-group row">
		<label id="elh_judgetype_JudgeType" for="x_JudgeType" class="<?php echo $judgetype_edit->LeftColumnClass ?>"><?php echo $judgetype->JudgeType->caption() ?><?php echo ($judgetype->JudgeType->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></label>
		<div class="<?php echo $judgetype_edit->RightColumnClass ?>"><div<?php echo $judgetype->JudgeType->cellAttributes() ?>>
<span id="el_judgetype_JudgeType">
<input type="text" data-table="judgetype" data-field="x_JudgeType" name="x_JudgeType" id="x_JudgeType" size="30" maxlength="50" placeholder="<?php echo HtmlEncode($judgetype->JudgeType->getPlaceHolder()) ?>" value="<?php echo $judgetype->JudgeType->EditValue ?>"<?php echo $judgetype->JudgeType->editAttributes() ?>>
</span>
<?php echo $judgetype->JudgeType->CustomMsg ?></div></div>
	</div>
<?php } else { ?>
	<tr id="r_JudgeType">
		<td class="<?php echo $judgetype_edit->TableLeftColumnClass ?>"><span id="elh_judgetype_JudgeType"><?php echo $judgetype->JudgeType->caption() ?><?php echo ($judgetype->JudgeType->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></span></td>
		<td<?php echo $judgetype->JudgeType->cellAttributes() ?>>
<span id="el_judgetype_JudgeType">
<input type="text" data-table="judgetype" data-field="x_JudgeType" name="x_JudgeType" id="x_JudgeType" size="30" maxlength="50" placeholder="<?php echo HtmlEncode($judgetype->JudgeType->getPlaceHolder()) ?>" value="<?php echo $judgetype->JudgeType->EditValue ?>"<?php echo $judgetype->JudgeType->editAttributes() ?>>
</span>
<?php echo $judgetype->JudgeType->CustomMsg ?></td>
	</tr>
<?php } ?>
<?php } ?>
<?php if ($judgetype->JudgeTypeEn->Visible) { // JudgeTypeEn ?>
<?php if ($judgetype_edit->IsMobileOrModal) { ?>
	<div id="r_JudgeTypeEn" class="form-group row">
		<label id="elh_judgetype_JudgeTypeEn" for="x_JudgeTypeEn" class="<?php echo $judgetype_edit->LeftColumnClass ?>"><?php echo $judgetype->JudgeTypeEn->caption() ?><?php echo ($judgetype->JudgeTypeEn->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></label>
		<div class="<?php echo $judgetype_edit->RightColumnClass ?>"><div<?php echo $judgetype->JudgeTypeEn->cellAttributes() ?>>
<span id="el_judgetype_JudgeTypeEn">
<input type="text" data-table="judgetype" data-field="x_JudgeTypeEn" name="x_JudgeTypeEn" id="x_JudgeTypeEn" size="30" maxlength="50" placeholder="<?php echo HtmlEncode($judgetype->JudgeTypeEn->getPlaceHolder()) ?>" value="<?php echo $judgetype->JudgeTypeEn->EditValue ?>"<?php echo $judgetype->JudgeTypeEn->editAttributes() ?>>
</span>
<?php echo $judgetype->JudgeTypeEn->CustomMsg ?></div></div>
	</div>
<?php } else { ?>
	<tr id="r_JudgeTypeEn">
		<td class="<?php echo $judgetype_edit->TableLeftColumnClass ?>"><span id="elh_judgetype_JudgeTypeEn"><?php echo $judgetype->JudgeTypeEn->caption() ?><?php echo ($judgetype->JudgeTypeEn->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></span></td>
		<td<?php echo $judgetype->JudgeTypeEn->cellAttributes() ?>>
<span id="el_judgetype_JudgeTypeEn">
<input type="text" data-table="judgetype" data-field="x_JudgeTypeEn" name="x_JudgeTypeEn" id="x_JudgeTypeEn" size="30" maxlength="50" placeholder="<?php echo HtmlEncode($judgetype->JudgeTypeEn->getPlaceHolder()) ?>" value="<?php echo $judgetype->JudgeTypeEn->EditValue ?>"<?php echo $judgetype->JudgeTypeEn->editAttributes() ?>>
</span>
<?php echo $judgetype->JudgeTypeEn->CustomMsg ?></td>
	</tr>
<?php } ?>
<?php } ?>
<?php if ($judgetype->Notes->Visible) { // Notes ?>
<?php if ($judgetype_edit->IsMobileOrModal) { ?>
	<div id="r_Notes" class="form-group row">
		<label id="elh_judgetype_Notes" for="x_Notes" class="<?php echo $judgetype_edit->LeftColumnClass ?>"><?php echo $judgetype->Notes->caption() ?><?php echo ($judgetype->Notes->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></label>
		<div class="<?php echo $judgetype_edit->RightColumnClass ?>"><div<?php echo $judgetype->Notes->cellAttributes() ?>>
<span id="el_judgetype_Notes">
<input type="text" data-table="judgetype" data-field="x_Notes" name="x_Notes" id="x_Notes" size="30" maxlength="100" placeholder="<?php echo HtmlEncode($judgetype->Notes->getPlaceHolder()) ?>" value="<?php echo $judgetype->Notes->EditValue ?>"<?php echo $judgetype->Notes->editAttributes() ?>>
</span>
<?php echo $judgetype->Notes->CustomMsg ?></div></div>
	</div>
<?php } else { ?>
	<tr id="r_Notes">
		<td class="<?php echo $judgetype_edit->TableLeftColumnClass ?>"><span id="elh_judgetype_Notes"><?php echo $judgetype->Notes->caption() ?><?php echo ($judgetype->Notes->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></span></td>
		<td<?php echo $judgetype->Notes->cellAttributes() ?>>
<span id="el_judgetype_Notes">
<input type="text" data-table="judgetype" data-field="x_Notes" name="x_Notes" id="x_Notes" size="30" maxlength="100" placeholder="<?php echo HtmlEncode($judgetype->Notes->getPlaceHolder()) ?>" value="<?php echo $judgetype->Notes->EditValue ?>"<?php echo $judgetype->Notes->editAttributes() ?>>
</span>
<?php echo $judgetype->Notes->CustomMsg ?></td>
	</tr>
<?php } ?>
<?php } ?>
<?php if ($judgetype_edit->IsMobileOrModal) { ?>
</div><!-- /page* -->
<?php } else { ?>
</table><!-- /table* -->
<?php } ?>
<span id="el_judgetype_JudgeTypeID">
<input type="hidden" data-table="judgetype" data-field="x_JudgeTypeID" name="x_JudgeTypeID" id="x_JudgeTypeID" value="<?php echo HtmlEncode($judgetype->JudgeTypeID->CurrentValue) ?>">
</span>
<?php if (!$judgetype_edit->IsModal) { ?>
<div class="form-group row"><!-- buttons .form-group -->
	<div class="<?php echo $judgetype_edit->OffsetColumnClass ?>"><!-- buttons offset -->
<button class="btn btn-primary ew-btn" name="btn-action" id="btn-action" type="submit"><?php echo $Language->phrase("SaveBtn") ?></button>
<button class="btn btn-default ew-btn" name="btn-cancel" id="btn-cancel" type="button" data-href="<?php echo $judgetype_edit->getReturnUrl() ?>"><?php echo $Language->phrase("CancelBtn") ?></button>
	</div><!-- /buttons offset -->
</div><!-- /buttons .form-group -->
<?php } ?>
<?php if (!$judgetype_edit->IsMobileOrModal) { ?>
</div><!-- /desktop -->
<?php } ?>
<?php if (!$judgetype_edit->IsModal) { ?>
<?php if (!isset($judgetype_edit->Pager)) $judgetype_edit->Pager = new PrevNextPager($judgetype_edit->StartRec, $judgetype_edit->DisplayRecs, $judgetype_edit->TotalRecs, $judgetype_edit->AutoHidePager) ?>
<?php if ($judgetype_edit->Pager->RecordCount > 0 && $judgetype_edit->Pager->Visible) { ?>
<div class="ew-pager">
<span><?php echo $Language->Phrase("Page") ?>&nbsp;</span>
<div class="ew-prev-next"><div class="input-group input-group-sm">
<div class="input-group-prepend">
<!-- first page button -->
	<?php if ($judgetype_edit->Pager->FirstButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerFirst") ?>" href="<?php echo $judgetype_edit->pageUrl() ?>start=<?php echo $judgetype_edit->Pager->FirstButton->Start ?>"><i class="icon-first ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerFirst") ?>"><i class="icon-first ew-icon"></i></a>
	<?php } ?>
<!-- previous page button -->
	<?php if ($judgetype_edit->Pager->PrevButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerPrevious") ?>" href="<?php echo $judgetype_edit->pageUrl() ?>start=<?php echo $judgetype_edit->Pager->PrevButton->Start ?>"><i class="icon-prev ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerPrevious") ?>"><i class="icon-prev ew-icon"></i></a>
	<?php } ?>
</div>
<!-- current page number -->
	<input class="form-control" type="text" name="<?php echo TABLE_PAGE_NO ?>" value="<?php echo $judgetype_edit->Pager->CurrentPage ?>">
<div class="input-group-append">
<!-- next page button -->
	<?php if ($judgetype_edit->Pager->NextButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerNext") ?>" href="<?php echo $judgetype_edit->pageUrl() ?>start=<?php echo $judgetype_edit->Pager->NextButton->Start ?>"><i class="icon-next ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerNext") ?>"><i class="icon-next ew-icon"></i></a>
	<?php } ?>
<!-- last page button -->
	<?php if ($judgetype_edit->Pager->LastButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerLast") ?>" href="<?php echo $judgetype_edit->pageUrl() ?>start=<?php echo $judgetype_edit->Pager->LastButton->Start ?>"><i class="icon-last ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerLast") ?>"><i class="icon-last ew-icon"></i></a>
	<?php } ?>
</div>
</div>
</div>
<span>&nbsp;<?php echo $Language->Phrase("of") ?>&nbsp;<?php echo $judgetype_edit->Pager->PageCount ?></span>
<div class="clearfix"></div>
</div>
<?php } ?>
<div class="clearfix"></div>
<?php } ?>
</form>
<?php
$judgetype_edit->showPageFooter();
if (DEBUG_ENABLED)
	echo GetDebugMessage();
?>
<script>

// Write your table-specific startup script here
// document.write("page loaded");

</script>
<?php include_once "footer.php" ?>
<?php
$judgetype_edit->terminate();
?>
